# Copyright (C) 2021 Radiotherapy AI Pty Ltd

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


def make_exe():
    dist = default_python_distribution(python_version = "3.9")

    policy = dist.make_python_packaging_policy()
    policy.resources_location = "filesystem-relative:lib"

    python_config = dist.make_python_interpreter_config()
    python_config.module_search_paths = ["$ORIGIN/lib"]
    python_config.run_module = "pymedphys"

    python_config.filesystem_importer = True
    python_config.oxidized_importer = False
    python_config.sys_frozen = True

    exe = dist.to_python_executable(
        name = "pymedphys",
        packaging_policy = policy,
        config = python_config,
    )
    exe.windows_runtime_dlls_mode = "always"
    exe.windows_subsystem = "console"

    exe.add_python_resources(exe.pip_install(["--use-feature", "in-tree-build", "-r", "requirements-cli.txt"]))
    exe.add_python_resources(exe.pip_install(["--use-feature", "in-tree-build", "-r", "requirements-icom.txt"]))
    exe.add_python_resources(exe.pip_install(["--use-feature", "in-tree-build", "-r", "requirements-tests.txt"]))
    exe.add_python_resources(exe.pip_install(["--use-feature", "in-tree-build", "."]))

    return exe

def make_embedded_resources(exe):
    return exe.to_embedded_resources()

def make_install(exe):
    # Create an object that represents our installed application file layout.
    files = FileManifest()

    # Add the generated executable to our install layout in the root directory.
    files.add_python_resource(".", exe)

    files.install("dist", replace = True)

    return files

def make_exe_installer(exe):
    files = FileManifest()
    files.add_python_resource(".", exe)

    installer = WiXInstaller("pymedphys", "PyMedPhys-0.38.0-dev4-Setup.msi")
    installer.add_simple_installer(
        "pymedphys",
        "PyMedPhys",
        "0.38.0",
        "PyMedPhys Contributors",
        files
    )

    installer.add_wxs_file('test.wxs')

    return installer

# Tell PyOxidizer about the build targets defined above.
register_target("exe", make_exe)
register_target("resources", make_embedded_resources, depends = ["exe"], default_build_script = True)
register_target("install", make_install, depends = ["exe"])
register_target("exe_installer", make_exe_installer, depends = ["exe"], default = True)

# Resolve whatever targets the invoker of this configuration file is requesting
# be resolved.
resolve_targets()
